@@ -14,35 +14,38 @@ class Fellowship(_ContinuumDataset):
         data_path: str = "",
         download: bool = True,
     ):
-        super().__init__(data_path, download)
+        super(Fellowship, self).__init__(data_path, download)
 
         self.datasets = [dataset(data_path, download) for dataset in dataset_list]
 
-    def init(self, train: bool) -> Tuple[np.ndarray, np.ndarray, None]:
-        x, y = [], []
+
+    def get_data(self) -> Tuple[np.ndarray, np.ndarray,  np.ndarray]:
+        x, y, t = [], [], []
         class_counter = 0
 
-        for dataset in self.datasets:
-            data = dataset.init(train)
+        for i, dataset in enumerate(self.datasets):
+            data = dataset.get_data()
 
             x.append(data[0])
             y.append(data[1] + class_counter)
+            t.append(np.ones(len(data[0])*i))
 
             class_counter += len(np.unique(data[1]))
 
         x = np.concatenate(x)
         y = np.concatenate(y)
+        t = np.concatenate(t)
 
-        return x, y, None
+        return x, y, t
 
 
 class MNISTFellowship(Fellowship):
 
     def __init__(self, data_path: str = "", download: bool = True) -> None:
-        super().__init__([MNIST, FashionMNIST, KMNIST], data_path, download)
+        super(MNISTFellowship, self).__init__([MNIST, FashionMNIST, KMNIST], data_path, download)
 
 
 class CIFARFellowship(Fellowship):
 
     def __init__(self, data_path: str = "", download: bool = True) -> None:
-        super().__init__([CIFAR10, CIFAR100], data_path, download)
+        super(CIFARFellowship, self).__init__([CIFAR10, CIFAR100], data_path, download)
